pub enum ChainState {
Ethereum(EthereumState),
Cosmos(CosmosState),
}Expand description
Chain-specific state variants
Variants
Implementations
Sourceimpl ChainState
impl ChainState
Sourcepub fn chain_type(&self) -> ChainType
pub fn chain_type(&self) -> ChainType
Get the chain type for this state
Sourcepub fn as_ethereum(&self) -> Option<&EthereumState>
pub fn as_ethereum(&self) -> Option<&EthereumState>
Get the Ethereum state if this is an Ethereum validator
Sourcepub fn as_ethereum_mut(&mut self) -> Option<&mut EthereumState>
pub fn as_ethereum_mut(&mut self) -> Option<&mut EthereumState>
Get the Ethereum state mutably if this is an Ethereum validator
Sourcepub fn as_cosmos(&self) -> Option<&CosmosState>
pub fn as_cosmos(&self) -> Option<&CosmosState>
Get the Cosmos state if this is a Cosmos validator
Sourcepub fn as_cosmos_mut(&mut self) -> Option<&mut CosmosState>
pub fn as_cosmos_mut(&mut self) -> Option<&mut CosmosState>
Get the Cosmos state mutably if this is a Cosmos validator